# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: btrdb.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='btrdb.proto',
  package='v5api',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0b\x62trdb.proto\x12\x05v5api\"Q\n\x0fRawValuesParams\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\x12\r\n\x05start\x18\x02 \x01(\x10\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x10\x12\x14\n\x0cversionMajor\x18\x04 \x01(\x04\"}\n\x11RawValuesResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\x12\x14\n\x0cversionMajor\x18\x02 \x01(\x04\x12\x14\n\x0cversionMinor\x18\x03 \x01(\x04\x12\x1f\n\x06values\x18\x04 \x03(\x0b\x32\x0f.v5api.RawPoint\"j\n\x14\x41lignedWindowsParams\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\x12\r\n\x05start\x18\x02 \x01(\x10\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x10\x12\x14\n\x0cversionMajor\x18\x04 \x01(\x04\x12\x12\n\npointWidth\x18\x05 \x01(\r\"\x83\x01\n\x16\x41lignedWindowsResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\x12\x14\n\x0cversionMajor\x18\x02 \x01(\x04\x12\x14\n\x0cversionMinor\x18\x03 \x01(\x04\x12 \n\x06values\x18\x04 \x03(\x0b\x32\x10.v5api.StatPoint\"m\n\rWindowsParams\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\x12\r\n\x05start\x18\x02 \x01(\x10\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x10\x12\x14\n\x0cversionMajor\x18\x04 \x01(\x04\x12\r\n\x05width\x18\x05 \x01(\x04\x12\r\n\x05\x64\x65pth\x18\x06 \x01(\r\"|\n\x0fWindowsResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\x12\x14\n\x0cversionMajor\x18\x02 \x01(\x04\x12\x14\n\x0cversionMinor\x18\x03 \x01(\x04\x12 \n\x06values\x18\x04 \x03(\x0b\x32\x10.v5api.StatPoint\"h\n\x10StreamInfoParams\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\x12\x13\n\x0bomitVersion\x18\x02 \x01(\x08\x12\x16\n\x0eomitDescriptor\x18\x03 \x01(\x08\x12\x19\n\x04role\x18\x64 \x01(\x0b\x32\x0b.v5api.Role\"\x8a\x01\n\x12StreamInfoResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\x12\x14\n\x0cversionMajor\x18\x02 \x01(\x04\x12\x14\n\x0cversionMinor\x18\x03 \x01(\x04\x12+\n\ndescriptor\x18\x04 \x01(\x0b\x32\x17.v5api.StreamDescriptor\"\x98\x01\n\x10StreamDescriptor\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\x12\x12\n\ncollection\x18\x02 \x01(\t\x12 \n\x04tags\x18\x03 \x03(\x0b\x32\x12.v5api.KeyOptValue\x12\'\n\x0b\x61nnotations\x18\x04 \x03(\x0b\x32\x12.v5api.KeyOptValue\x12\x17\n\x0fpropertyVersion\x18\x05 \x01(\x04\"\x82\x01\n\x1aSetStreamAnnotationsParams\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\x12\x1f\n\x17\x65xpectedPropertyVersion\x18\x02 \x01(\x04\x12#\n\x07\x63hanges\x18\x03 \x03(\x0b\x32\x12.v5api.KeyOptValue\x12\x10\n\x08removals\x18\x04 \x03(\t\";\n\x1cSetStreamAnnotationsResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\"\x8a\x01\n\x13SetStreamTagsParams\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\x12\x1f\n\x17\x65xpectedPropertyVersion\x18\x02 \x01(\x04\x12 \n\x04tags\x18\x03 \x03(\x0b\x32\x12.v5api.KeyOptValue\x12\x12\n\ncollection\x18\x04 \x01(\t\x12\x0e\n\x06remove\x18\x05 \x03(\t\"4\n\x15SetStreamTagsResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\"{\n\x0c\x43reateParams\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\x12\x12\n\ncollection\x18\x02 \x01(\t\x12 \n\x04tags\x18\x03 \x03(\x0b\x32\x12.v5api.KeyOptValue\x12\'\n\x0b\x61nnotations\x18\x04 \x03(\x0b\x32\x12.v5api.KeyOptValue\"-\n\x0e\x43reateResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\"@\n\x13MetadataUsageParams\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12\x19\n\x04role\x18\x64 \x01(\x0b\x32\x0b.v5api.Role\"y\n\x15MetadataUsageResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\x12\x1d\n\x04tags\x18\x02 \x03(\x0b\x32\x0f.v5api.KeyCount\x12$\n\x0b\x61nnotations\x18\x03 \x03(\x0b\x32\x0f.v5api.KeyCount\"&\n\x08KeyCount\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\"B\n\x15ListCollectionsParams\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12\x19\n\x04role\x18\x64 \x01(\x0b\x32\x0b.v5api.Role\"K\n\x17ListCollectionsResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\x12\x13\n\x0b\x63ollections\x18\x02 \x03(\t\"\xab\x01\n\x13LookupStreamsParams\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\x1a\n\x12isCollectionPrefix\x18\x02 \x01(\x08\x12 \n\x04tags\x18\x03 \x03(\x0b\x32\x12.v5api.KeyOptValue\x12\'\n\x0b\x61nnotations\x18\x04 \x03(\x0b\x32\x12.v5api.KeyOptValue\x12\x19\n\x04role\x18\x64 \x01(\x0b\x32\x0b.v5api.Role\"^\n\x15LookupStreamsResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\x12(\n\x07results\x18\x02 \x03(\x0b\x32\x17.v5api.StreamDescriptor\"S\n\rNearestParams\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\x12\x0c\n\x04time\x18\x02 \x01(\x10\x12\x14\n\x0cversionMajor\x18\x03 \x01(\x04\x12\x10\n\x08\x62\x61\x63kward\x18\x04 \x01(\x08\"z\n\x0fNearestResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\x12\x14\n\x0cversionMajor\x18\x02 \x01(\x04\x12\x14\n\x0cversionMinor\x18\x03 \x01(\x04\x12\x1e\n\x05value\x18\x04 \x01(\x0b\x32\x0f.v5api.RawPoint\"U\n\rChangesParams\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\x12\x11\n\tfromMajor\x18\x02 \x01(\x04\x12\x0f\n\x07toMajor\x18\x03 \x01(\x04\x12\x12\n\nresolution\x18\x04 \x01(\r\"\x7f\n\x0f\x43hangesResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\x12\x14\n\x0cversionMajor\x18\x02 \x01(\x04\x12\x14\n\x0cversionMinor\x18\x03 \x01(\x04\x12#\n\x06ranges\x18\x04 \x03(\x0b\x32\x13.v5api.ChangedRange\"u\n\x0cInsertParams\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\x12\x0c\n\x04sync\x18\x02 \x01(\x08\x12(\n\x0cmerge_policy\x18\x04 \x01(\x0e\x32\x12.v5api.MergePolicy\x12\x1f\n\x06values\x18\x03 \x03(\x0b\x32\x0f.v5api.RawPoint\"Y\n\x0eInsertResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\x12\x14\n\x0cversionMajor\x18\x02 \x01(\x04\x12\x14\n\x0cversionMinor\x18\x03 \x01(\x04\"8\n\x0c\x44\x65leteParams\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\x12\r\n\x05start\x18\x02 \x01(\x10\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x10\"Y\n\x0e\x44\x65leteResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\x12\x14\n\x0cversionMajor\x18\x02 \x01(\x04\x12\x14\n\x0cversionMinor\x18\x03 \x01(\x04\"\x0c\n\nInfoParams\"\xa2\x01\n\x0cInfoResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\x12\x19\n\x04mash\x18\x02 \x01(\x0b\x32\x0b.v5api.Mash\x12\x14\n\x0cmajorVersion\x18\x03 \x01(\r\x12\x14\n\x0cminorVersion\x18\x04 \x01(\r\x12\r\n\x05\x62uild\x18\x05 \x01(\t\x12\x1f\n\x05proxy\x18\x06 \x01(\x0b\x32\x10.v5api.ProxyInfo\"#\n\tProxyInfo\x12\x16\n\x0eproxyEndpoints\x18\x01 \x03(\t\"1\n\x11\x46\x61ultInjectParams\x12\x0c\n\x04type\x18\x01 \x01(\x04\x12\x0e\n\x06params\x18\x02 \x01(\x0c\">\n\x13\x46\x61ultInjectResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\x12\n\n\x02rv\x18\x02 \x01(\x0c\"\x1b\n\x0b\x46lushParams\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\"X\n\rFlushResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\x12\x14\n\x0cversionMajor\x18\x02 \x01(\x04\x12\x14\n\x0cversionMinor\x18\x03 \x01(\x04\" \n\x10ObliterateParams\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\"1\n\x12ObliterateResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\"\'\n\x08RawPoint\x12\x0c\n\x04time\x18\x01 \x01(\x10\x12\r\n\x05value\x18\x02 \x01(\x01\"`\n\tStatPoint\x12\x0c\n\x04time\x18\x01 \x01(\x10\x12\x0b\n\x03min\x18\x02 \x01(\x01\x12\x0c\n\x04mean\x18\x03 \x01(\x01\x12\x0b\n\x03max\x18\x04 \x01(\x01\x12\r\n\x05\x63ount\x18\x05 \x01(\x06\x12\x0e\n\x06stddev\x18\x06 \x01(\x01\"*\n\x0c\x43hangedRange\x12\r\n\x05start\x18\x01 \x01(\x10\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x10\">\n\x06Status\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x19\n\x04mash\x18\x03 \x01(\x0b\x32\x0b.v5api.Mash\"\x98\x01\n\x04Mash\x12\x10\n\x08revision\x18\x01 \x01(\x03\x12\x0e\n\x06leader\x18\x02 \x01(\t\x12\x16\n\x0eleaderRevision\x18\x03 \x01(\x03\x12\x13\n\x0btotalWeight\x18\x04 \x01(\x03\x12\x0f\n\x07healthy\x18\x05 \x01(\x08\x12\x10\n\x08unmapped\x18\x06 \x01(\x01\x12\x1e\n\x07members\x18\x07 \x03(\x0b\x32\r.v5api.Member\"\xc3\x01\n\x06Member\x12\x0c\n\x04hash\x18\x01 \x01(\r\x12\x10\n\x08nodename\x18\x02 \x01(\t\x12\n\n\x02up\x18\x03 \x01(\x08\x12\n\n\x02in\x18\x04 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x05 \x01(\x08\x12\r\n\x05start\x18\x06 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x07 \x01(\x03\x12\x0e\n\x06weight\x18\x08 \x01(\x03\x12\x16\n\x0ereadPreference\x18\t \x01(\x01\x12\x15\n\rhttpEndpoints\x18\n \x01(\t\x12\x15\n\rgrpcEndpoints\x18\x0b \x01(\t\"8\n\x0bKeyOptValue\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1c\n\x03val\x18\x02 \x01(\x0b\x32\x0f.v5api.OptValue\"\x19\n\x08OptValue\x12\r\n\x05value\x18\x01 \x01(\t\"&\n\x08KeyValue\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"?\n\x0fStreamCSVConfig\x12\x0f\n\x07version\x18\x01 \x01(\x04\x12\r\n\x05label\x18\x02 \x01(\t\x12\x0c\n\x04uuid\x18\x03 \x01(\x0c\"\x9d\x02\n\x11GenerateCSVParams\x12\x35\n\tqueryType\x18\x01 \x01(\x0e\x32\".v5api.GenerateCSVParams.QueryType\x12\x11\n\tstartTime\x18\x02 \x01(\x03\x12\x0f\n\x07\x65ndTime\x18\x03 \x01(\x03\x12\x12\n\nwindowSize\x18\x04 \x01(\x04\x12\r\n\x05\x64\x65pth\x18\x05 \x01(\r\x12\x17\n\x0fincludeVersions\x18\x06 \x01(\x08\x12\'\n\x07streams\x18\x07 \x03(\x0b\x32\x16.v5api.StreamCSVConfig\"H\n\tQueryType\x12\x19\n\x15\x41LIGNED_WINDOWS_QUERY\x10\x00\x12\x11\n\rWINDOWS_QUERY\x10\x01\x12\r\n\tRAW_QUERY\x10\x02\"Q\n\x13GenerateCSVResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\x12\x10\n\x08isHeader\x18\x02 \x01(\x08\x12\x0b\n\x03row\x18\x03 \x03(\t\"J\n\x0eSQLQueryParams\x12\r\n\x05query\x18\x01 \x01(\t\x12\x0e\n\x06params\x18\x02 \x03(\t\x12\x19\n\x04role\x18\x64 \x01(\x0b\x32\x0b.v5api.Role\"D\n\x10SQLQueryResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\x12\x13\n\x0bSQLQueryRow\x18\x02 \x03(\x0c\"\x14\n\x04Role\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x94\x01\n\x19SetCompactionConfigParams\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\x12\x18\n\x10\x43ompactedVersion\x18\x02 \x01(\x04\x12>\n\x17reducedResolutionRanges\x18\x03 \x03(\x0b\x32\x1d.v5api.ReducedResolutionRange\x12\x0f\n\x07unused0\x18\x04 \x01(\x04\":\n\x1bSetCompactionConfigResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\")\n\x19GetCompactionConfigParams\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\"\xc1\x01\n\x1bGetCompactionConfigResponse\x12\x1b\n\x04stat\x18\x01 \x01(\x0b\x32\r.v5api.Status\x12\x1a\n\x12LatestMajorVersion\x18\x02 \x01(\x04\x12\x18\n\x10\x43ompactedVersion\x18\x03 \x01(\x04\x12>\n\x17reducedResolutionRanges\x18\x04 \x03(\x0b\x32\x1d.v5api.ReducedResolutionRange\x12\x0f\n\x07unused0\x18\x05 \x01(\x04\"H\n\x16ReducedResolutionRange\x12\r\n\x05Start\x18\x01 \x01(\x03\x12\x0b\n\x03\x45nd\x18\x02 \x01(\x03\x12\x12\n\nResolution\x18\x03 \x01(\r*<\n\x0bMergePolicy\x12\t\n\x05NEVER\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\n\n\x06RETAIN\x10\x02\x12\x0b\n\x07REPLACE\x10\x03\x32\xb3\n\n\x05\x42TrDB\x12?\n\tRawValues\x12\x16.v5api.RawValuesParams\x1a\x18.v5api.RawValuesResponse0\x01\x12N\n\x0e\x41lignedWindows\x12\x1b.v5api.AlignedWindowsParams\x1a\x1d.v5api.AlignedWindowsResponse0\x01\x12\x39\n\x07Windows\x12\x14.v5api.WindowsParams\x1a\x16.v5api.WindowsResponse0\x01\x12@\n\nStreamInfo\x12\x17.v5api.StreamInfoParams\x1a\x19.v5api.StreamInfoResponse\x12^\n\x14SetStreamAnnotations\x12!.v5api.SetStreamAnnotationsParams\x1a#.v5api.SetStreamAnnotationsResponse\x12I\n\rSetStreamTags\x12\x1a.v5api.SetStreamTagsParams\x1a\x1c.v5api.SetStreamTagsResponse\x12\x34\n\x06\x43reate\x12\x13.v5api.CreateParams\x1a\x15.v5api.CreateResponse\x12Q\n\x0fListCollections\x12\x1c.v5api.ListCollectionsParams\x1a\x1e.v5api.ListCollectionsResponse0\x01\x12K\n\rLookupStreams\x12\x1a.v5api.LookupStreamsParams\x1a\x1c.v5api.LookupStreamsResponse0\x01\x12\x37\n\x07Nearest\x12\x14.v5api.NearestParams\x1a\x16.v5api.NearestResponse\x12\x39\n\x07\x43hanges\x12\x14.v5api.ChangesParams\x1a\x16.v5api.ChangesResponse0\x01\x12\x34\n\x06Insert\x12\x13.v5api.InsertParams\x1a\x15.v5api.InsertResponse\x12\x34\n\x06\x44\x65lete\x12\x13.v5api.DeleteParams\x1a\x15.v5api.DeleteResponse\x12.\n\x04Info\x12\x11.v5api.InfoParams\x1a\x13.v5api.InfoResponse\x12\x43\n\x0b\x46\x61ultInject\x12\x18.v5api.FaultInjectParams\x1a\x1a.v5api.FaultInjectResponse\x12\x31\n\x05\x46lush\x12\x12.v5api.FlushParams\x1a\x14.v5api.FlushResponse\x12@\n\nObliterate\x12\x17.v5api.ObliterateParams\x1a\x19.v5api.ObliterateResponse\x12L\n\x10GetMetadataUsage\x12\x1a.v5api.MetadataUsageParams\x1a\x1c.v5api.MetadataUsageResponse\x12\x45\n\x0bGenerateCSV\x12\x18.v5api.GenerateCSVParams\x1a\x1a.v5api.GenerateCSVResponse0\x01\x12<\n\x08SQLQuery\x12\x15.v5api.SQLQueryParams\x1a\x17.v5api.SQLQueryResponse0\x01\x62\x06proto3')
)

_MERGEPOLICY = _descriptor.EnumDescriptor(
  name='MergePolicy',
  full_name='v5api.MergePolicy',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NEVER', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RETAIN', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REPLACE', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5490,
  serialized_end=5550,
)
_sym_db.RegisterEnumDescriptor(_MERGEPOLICY)

MergePolicy = enum_type_wrapper.EnumTypeWrapper(_MERGEPOLICY)
NEVER = 0
EQUAL = 1
RETAIN = 2
REPLACE = 3


_GENERATECSVPARAMS_QUERYTYPE = _descriptor.EnumDescriptor(
  name='QueryType',
  full_name='v5api.GenerateCSVParams.QueryType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALIGNED_WINDOWS_QUERY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WINDOWS_QUERY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAW_QUERY', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4641,
  serialized_end=4713,
)
_sym_db.RegisterEnumDescriptor(_GENERATECSVPARAMS_QUERYTYPE)


_RAWVALUESPARAMS = _descriptor.Descriptor(
  name='RawValuesParams',
  full_name='v5api.RawValuesParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='v5api.RawValuesParams.uuid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='v5api.RawValuesParams.start', index=1,
      number=2, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='v5api.RawValuesParams.end', index=2,
      number=3, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMajor', full_name='v5api.RawValuesParams.versionMajor', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22,
  serialized_end=103,
)


_RAWVALUESRESPONSE = _descriptor.Descriptor(
  name='RawValuesResponse',
  full_name='v5api.RawValuesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.RawValuesResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMajor', full_name='v5api.RawValuesResponse.versionMajor', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMinor', full_name='v5api.RawValuesResponse.versionMinor', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='v5api.RawValuesResponse.values', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=230,
)


_ALIGNEDWINDOWSPARAMS = _descriptor.Descriptor(
  name='AlignedWindowsParams',
  full_name='v5api.AlignedWindowsParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='v5api.AlignedWindowsParams.uuid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='v5api.AlignedWindowsParams.start', index=1,
      number=2, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='v5api.AlignedWindowsParams.end', index=2,
      number=3, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMajor', full_name='v5api.AlignedWindowsParams.versionMajor', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pointWidth', full_name='v5api.AlignedWindowsParams.pointWidth', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=338,
)


_ALIGNEDWINDOWSRESPONSE = _descriptor.Descriptor(
  name='AlignedWindowsResponse',
  full_name='v5api.AlignedWindowsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.AlignedWindowsResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMajor', full_name='v5api.AlignedWindowsResponse.versionMajor', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMinor', full_name='v5api.AlignedWindowsResponse.versionMinor', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='v5api.AlignedWindowsResponse.values', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=341,
  serialized_end=472,
)


_WINDOWSPARAMS = _descriptor.Descriptor(
  name='WindowsParams',
  full_name='v5api.WindowsParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='v5api.WindowsParams.uuid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='v5api.WindowsParams.start', index=1,
      number=2, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='v5api.WindowsParams.end', index=2,
      number=3, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMajor', full_name='v5api.WindowsParams.versionMajor', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='width', full_name='v5api.WindowsParams.width', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='depth', full_name='v5api.WindowsParams.depth', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=474,
  serialized_end=583,
)


_WINDOWSRESPONSE = _descriptor.Descriptor(
  name='WindowsResponse',
  full_name='v5api.WindowsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.WindowsResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMajor', full_name='v5api.WindowsResponse.versionMajor', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMinor', full_name='v5api.WindowsResponse.versionMinor', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='v5api.WindowsResponse.values', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=585,
  serialized_end=709,
)


_STREAMINFOPARAMS = _descriptor.Descriptor(
  name='StreamInfoParams',
  full_name='v5api.StreamInfoParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='v5api.StreamInfoParams.uuid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='omitVersion', full_name='v5api.StreamInfoParams.omitVersion', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='omitDescriptor', full_name='v5api.StreamInfoParams.omitDescriptor', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role', full_name='v5api.StreamInfoParams.role', index=3,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=711,
  serialized_end=815,
)


_STREAMINFORESPONSE = _descriptor.Descriptor(
  name='StreamInfoResponse',
  full_name='v5api.StreamInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.StreamInfoResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMajor', full_name='v5api.StreamInfoResponse.versionMajor', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMinor', full_name='v5api.StreamInfoResponse.versionMinor', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='descriptor', full_name='v5api.StreamInfoResponse.descriptor', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=818,
  serialized_end=956,
)


_STREAMDESCRIPTOR = _descriptor.Descriptor(
  name='StreamDescriptor',
  full_name='v5api.StreamDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='v5api.StreamDescriptor.uuid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection', full_name='v5api.StreamDescriptor.collection', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='v5api.StreamDescriptor.tags', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='v5api.StreamDescriptor.annotations', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='propertyVersion', full_name='v5api.StreamDescriptor.propertyVersion', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=959,
  serialized_end=1111,
)


_SETSTREAMANNOTATIONSPARAMS = _descriptor.Descriptor(
  name='SetStreamAnnotationsParams',
  full_name='v5api.SetStreamAnnotationsParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='v5api.SetStreamAnnotationsParams.uuid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expectedPropertyVersion', full_name='v5api.SetStreamAnnotationsParams.expectedPropertyVersion', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='changes', full_name='v5api.SetStreamAnnotationsParams.changes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='removals', full_name='v5api.SetStreamAnnotationsParams.removals', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1114,
  serialized_end=1244,
)


_SETSTREAMANNOTATIONSRESPONSE = _descriptor.Descriptor(
  name='SetStreamAnnotationsResponse',
  full_name='v5api.SetStreamAnnotationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.SetStreamAnnotationsResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1246,
  serialized_end=1305,
)


_SETSTREAMTAGSPARAMS = _descriptor.Descriptor(
  name='SetStreamTagsParams',
  full_name='v5api.SetStreamTagsParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='v5api.SetStreamTagsParams.uuid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expectedPropertyVersion', full_name='v5api.SetStreamTagsParams.expectedPropertyVersion', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='v5api.SetStreamTagsParams.tags', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection', full_name='v5api.SetStreamTagsParams.collection', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='v5api.SetStreamTagsParams.remove', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1308,
  serialized_end=1446,
)


_SETSTREAMTAGSRESPONSE = _descriptor.Descriptor(
  name='SetStreamTagsResponse',
  full_name='v5api.SetStreamTagsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.SetStreamTagsResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1448,
  serialized_end=1500,
)


_CREATEPARAMS = _descriptor.Descriptor(
  name='CreateParams',
  full_name='v5api.CreateParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='v5api.CreateParams.uuid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection', full_name='v5api.CreateParams.collection', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='v5api.CreateParams.tags', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='v5api.CreateParams.annotations', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1502,
  serialized_end=1625,
)


_CREATERESPONSE = _descriptor.Descriptor(
  name='CreateResponse',
  full_name='v5api.CreateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.CreateResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1627,
  serialized_end=1672,
)


_METADATAUSAGEPARAMS = _descriptor.Descriptor(
  name='MetadataUsageParams',
  full_name='v5api.MetadataUsageParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefix', full_name='v5api.MetadataUsageParams.prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role', full_name='v5api.MetadataUsageParams.role', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1674,
  serialized_end=1738,
)


_METADATAUSAGERESPONSE = _descriptor.Descriptor(
  name='MetadataUsageResponse',
  full_name='v5api.MetadataUsageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.MetadataUsageResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='v5api.MetadataUsageResponse.tags', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='v5api.MetadataUsageResponse.annotations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1740,
  serialized_end=1861,
)


_KEYCOUNT = _descriptor.Descriptor(
  name='KeyCount',
  full_name='v5api.KeyCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='v5api.KeyCount.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='v5api.KeyCount.count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1863,
  serialized_end=1901,
)


_LISTCOLLECTIONSPARAMS = _descriptor.Descriptor(
  name='ListCollectionsParams',
  full_name='v5api.ListCollectionsParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefix', full_name='v5api.ListCollectionsParams.prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role', full_name='v5api.ListCollectionsParams.role', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1903,
  serialized_end=1969,
)


_LISTCOLLECTIONSRESPONSE = _descriptor.Descriptor(
  name='ListCollectionsResponse',
  full_name='v5api.ListCollectionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.ListCollectionsResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collections', full_name='v5api.ListCollectionsResponse.collections', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1971,
  serialized_end=2046,
)


_LOOKUPSTREAMSPARAMS = _descriptor.Descriptor(
  name='LookupStreamsParams',
  full_name='v5api.LookupStreamsParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection', full_name='v5api.LookupStreamsParams.collection', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isCollectionPrefix', full_name='v5api.LookupStreamsParams.isCollectionPrefix', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='v5api.LookupStreamsParams.tags', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='v5api.LookupStreamsParams.annotations', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role', full_name='v5api.LookupStreamsParams.role', index=4,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2049,
  serialized_end=2220,
)


_LOOKUPSTREAMSRESPONSE = _descriptor.Descriptor(
  name='LookupStreamsResponse',
  full_name='v5api.LookupStreamsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.LookupStreamsResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='v5api.LookupStreamsResponse.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2222,
  serialized_end=2316,
)


_NEARESTPARAMS = _descriptor.Descriptor(
  name='NearestParams',
  full_name='v5api.NearestParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='v5api.NearestParams.uuid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='v5api.NearestParams.time', index=1,
      number=2, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMajor', full_name='v5api.NearestParams.versionMajor', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backward', full_name='v5api.NearestParams.backward', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2318,
  serialized_end=2401,
)


_NEARESTRESPONSE = _descriptor.Descriptor(
  name='NearestResponse',
  full_name='v5api.NearestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.NearestResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMajor', full_name='v5api.NearestResponse.versionMajor', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMinor', full_name='v5api.NearestResponse.versionMinor', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='v5api.NearestResponse.value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2403,
  serialized_end=2525,
)


_CHANGESPARAMS = _descriptor.Descriptor(
  name='ChangesParams',
  full_name='v5api.ChangesParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='v5api.ChangesParams.uuid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fromMajor', full_name='v5api.ChangesParams.fromMajor', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='toMajor', full_name='v5api.ChangesParams.toMajor', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resolution', full_name='v5api.ChangesParams.resolution', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2527,
  serialized_end=2612,
)


_CHANGESRESPONSE = _descriptor.Descriptor(
  name='ChangesResponse',
  full_name='v5api.ChangesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.ChangesResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMajor', full_name='v5api.ChangesResponse.versionMajor', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMinor', full_name='v5api.ChangesResponse.versionMinor', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ranges', full_name='v5api.ChangesResponse.ranges', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2614,
  serialized_end=2741,
)


_INSERTPARAMS = _descriptor.Descriptor(
  name='InsertParams',
  full_name='v5api.InsertParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='v5api.InsertParams.uuid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sync', full_name='v5api.InsertParams.sync', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merge_policy', full_name='v5api.InsertParams.merge_policy', index=2,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='v5api.InsertParams.values', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2743,
  serialized_end=2860,
)


_INSERTRESPONSE = _descriptor.Descriptor(
  name='InsertResponse',
  full_name='v5api.InsertResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.InsertResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMajor', full_name='v5api.InsertResponse.versionMajor', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMinor', full_name='v5api.InsertResponse.versionMinor', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2862,
  serialized_end=2951,
)


_DELETEPARAMS = _descriptor.Descriptor(
  name='DeleteParams',
  full_name='v5api.DeleteParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='v5api.DeleteParams.uuid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='v5api.DeleteParams.start', index=1,
      number=2, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='v5api.DeleteParams.end', index=2,
      number=3, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2953,
  serialized_end=3009,
)


_DELETERESPONSE = _descriptor.Descriptor(
  name='DeleteResponse',
  full_name='v5api.DeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.DeleteResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMajor', full_name='v5api.DeleteResponse.versionMajor', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMinor', full_name='v5api.DeleteResponse.versionMinor', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3011,
  serialized_end=3100,
)


_INFOPARAMS = _descriptor.Descriptor(
  name='InfoParams',
  full_name='v5api.InfoParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3102,
  serialized_end=3114,
)


_INFORESPONSE = _descriptor.Descriptor(
  name='InfoResponse',
  full_name='v5api.InfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.InfoResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mash', full_name='v5api.InfoResponse.mash', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='majorVersion', full_name='v5api.InfoResponse.majorVersion', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minorVersion', full_name='v5api.InfoResponse.minorVersion', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='build', full_name='v5api.InfoResponse.build', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proxy', full_name='v5api.InfoResponse.proxy', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3117,
  serialized_end=3279,
)


_PROXYINFO = _descriptor.Descriptor(
  name='ProxyInfo',
  full_name='v5api.ProxyInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='proxyEndpoints', full_name='v5api.ProxyInfo.proxyEndpoints', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3281,
  serialized_end=3316,
)


_FAULTINJECTPARAMS = _descriptor.Descriptor(
  name='FaultInjectParams',
  full_name='v5api.FaultInjectParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='v5api.FaultInjectParams.type', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='v5api.FaultInjectParams.params', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3318,
  serialized_end=3367,
)


_FAULTINJECTRESPONSE = _descriptor.Descriptor(
  name='FaultInjectResponse',
  full_name='v5api.FaultInjectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.FaultInjectResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rv', full_name='v5api.FaultInjectResponse.rv', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3369,
  serialized_end=3431,
)


_FLUSHPARAMS = _descriptor.Descriptor(
  name='FlushParams',
  full_name='v5api.FlushParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='v5api.FlushParams.uuid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3433,
  serialized_end=3460,
)


_FLUSHRESPONSE = _descriptor.Descriptor(
  name='FlushResponse',
  full_name='v5api.FlushResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.FlushResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMajor', full_name='v5api.FlushResponse.versionMajor', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionMinor', full_name='v5api.FlushResponse.versionMinor', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3462,
  serialized_end=3550,
)


_OBLITERATEPARAMS = _descriptor.Descriptor(
  name='ObliterateParams',
  full_name='v5api.ObliterateParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='v5api.ObliterateParams.uuid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3552,
  serialized_end=3584,
)


_OBLITERATERESPONSE = _descriptor.Descriptor(
  name='ObliterateResponse',
  full_name='v5api.ObliterateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.ObliterateResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3586,
  serialized_end=3635,
)


_RAWPOINT = _descriptor.Descriptor(
  name='RawPoint',
  full_name='v5api.RawPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='v5api.RawPoint.time', index=0,
      number=1, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='v5api.RawPoint.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3637,
  serialized_end=3676,
)


_STATPOINT = _descriptor.Descriptor(
  name='StatPoint',
  full_name='v5api.StatPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='v5api.StatPoint.time', index=0,
      number=1, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min', full_name='v5api.StatPoint.min', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mean', full_name='v5api.StatPoint.mean', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max', full_name='v5api.StatPoint.max', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='v5api.StatPoint.count', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stddev', full_name='v5api.StatPoint.stddev', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3678,
  serialized_end=3774,
)


_CHANGEDRANGE = _descriptor.Descriptor(
  name='ChangedRange',
  full_name='v5api.ChangedRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='v5api.ChangedRange.start', index=0,
      number=1, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='v5api.ChangedRange.end', index=1,
      number=2, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3776,
  serialized_end=3818,
)


_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='v5api.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='v5api.Status.code', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg', full_name='v5api.Status.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mash', full_name='v5api.Status.mash', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3820,
  serialized_end=3882,
)


_MASH = _descriptor.Descriptor(
  name='Mash',
  full_name='v5api.Mash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='revision', full_name='v5api.Mash.revision', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leader', full_name='v5api.Mash.leader', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leaderRevision', full_name='v5api.Mash.leaderRevision', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalWeight', full_name='v5api.Mash.totalWeight', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v5api.Mash.healthy', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unmapped', full_name='v5api.Mash.unmapped', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='members', full_name='v5api.Mash.members', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3885,
  serialized_end=4037,
)


_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='v5api.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='v5api.Member.hash', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nodename', full_name='v5api.Member.nodename', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='up', full_name='v5api.Member.up', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in', full_name='v5api.Member.in', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='v5api.Member.enabled', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='v5api.Member.start', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='v5api.Member.end', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weight', full_name='v5api.Member.weight', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='readPreference', full_name='v5api.Member.readPreference', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='httpEndpoints', full_name='v5api.Member.httpEndpoints', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='grpcEndpoints', full_name='v5api.Member.grpcEndpoints', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4040,
  serialized_end=4235,
)


_KEYOPTVALUE = _descriptor.Descriptor(
  name='KeyOptValue',
  full_name='v5api.KeyOptValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='v5api.KeyOptValue.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='v5api.KeyOptValue.val', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4237,
  serialized_end=4293,
)


_OPTVALUE = _descriptor.Descriptor(
  name='OptValue',
  full_name='v5api.OptValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='v5api.OptValue.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4295,
  serialized_end=4320,
)


_KEYVALUE = _descriptor.Descriptor(
  name='KeyValue',
  full_name='v5api.KeyValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='v5api.KeyValue.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='v5api.KeyValue.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4322,
  serialized_end=4360,
)


_STREAMCSVCONFIG = _descriptor.Descriptor(
  name='StreamCSVConfig',
  full_name='v5api.StreamCSVConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='v5api.StreamCSVConfig.version', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='v5api.StreamCSVConfig.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='v5api.StreamCSVConfig.uuid', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4362,
  serialized_end=4425,
)


_GENERATECSVPARAMS = _descriptor.Descriptor(
  name='GenerateCSVParams',
  full_name='v5api.GenerateCSVParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='queryType', full_name='v5api.GenerateCSVParams.queryType', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='v5api.GenerateCSVParams.startTime', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='v5api.GenerateCSVParams.endTime', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='windowSize', full_name='v5api.GenerateCSVParams.windowSize', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='depth', full_name='v5api.GenerateCSVParams.depth', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='includeVersions', full_name='v5api.GenerateCSVParams.includeVersions', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streams', full_name='v5api.GenerateCSVParams.streams', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GENERATECSVPARAMS_QUERYTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4428,
  serialized_end=4713,
)


_GENERATECSVRESPONSE = _descriptor.Descriptor(
  name='GenerateCSVResponse',
  full_name='v5api.GenerateCSVResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.GenerateCSVResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isHeader', full_name='v5api.GenerateCSVResponse.isHeader', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row', full_name='v5api.GenerateCSVResponse.row', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4715,
  serialized_end=4796,
)


_SQLQUERYPARAMS = _descriptor.Descriptor(
  name='SQLQueryParams',
  full_name='v5api.SQLQueryParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='v5api.SQLQueryParams.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='v5api.SQLQueryParams.params', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role', full_name='v5api.SQLQueryParams.role', index=2,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4798,
  serialized_end=4872,
)


_SQLQUERYRESPONSE = _descriptor.Descriptor(
  name='SQLQueryResponse',
  full_name='v5api.SQLQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.SQLQueryResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SQLQueryRow', full_name='v5api.SQLQueryResponse.SQLQueryRow', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4874,
  serialized_end=4942,
)


_ROLE = _descriptor.Descriptor(
  name='Role',
  full_name='v5api.Role',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='v5api.Role.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4944,
  serialized_end=4964,
)


_SETCOMPACTIONCONFIGPARAMS = _descriptor.Descriptor(
  name='SetCompactionConfigParams',
  full_name='v5api.SetCompactionConfigParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='v5api.SetCompactionConfigParams.uuid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='CompactedVersion', full_name='v5api.SetCompactionConfigParams.CompactedVersion', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reducedResolutionRanges', full_name='v5api.SetCompactionConfigParams.reducedResolutionRanges', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unused0', full_name='v5api.SetCompactionConfigParams.unused0', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4967,
  serialized_end=5115,
)


_SETCOMPACTIONCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetCompactionConfigResponse',
  full_name='v5api.SetCompactionConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.SetCompactionConfigResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5117,
  serialized_end=5175,
)


_GETCOMPACTIONCONFIGPARAMS = _descriptor.Descriptor(
  name='GetCompactionConfigParams',
  full_name='v5api.GetCompactionConfigParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='v5api.GetCompactionConfigParams.uuid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5177,
  serialized_end=5218,
)


_GETCOMPACTIONCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetCompactionConfigResponse',
  full_name='v5api.GetCompactionConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='v5api.GetCompactionConfigResponse.stat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='LatestMajorVersion', full_name='v5api.GetCompactionConfigResponse.LatestMajorVersion', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='CompactedVersion', full_name='v5api.GetCompactionConfigResponse.CompactedVersion', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reducedResolutionRanges', full_name='v5api.GetCompactionConfigResponse.reducedResolutionRanges', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unused0', full_name='v5api.GetCompactionConfigResponse.unused0', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5221,
  serialized_end=5414,
)


_REDUCEDRESOLUTIONRANGE = _descriptor.Descriptor(
  name='ReducedResolutionRange',
  full_name='v5api.ReducedResolutionRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Start', full_name='v5api.ReducedResolutionRange.Start', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='End', full_name='v5api.ReducedResolutionRange.End', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Resolution', full_name='v5api.ReducedResolutionRange.Resolution', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5416,
  serialized_end=5488,
)

_RAWVALUESRESPONSE.fields_by_name['stat'].message_type = _STATUS
_RAWVALUESRESPONSE.fields_by_name['values'].message_type = _RAWPOINT
_ALIGNEDWINDOWSRESPONSE.fields_by_name['stat'].message_type = _STATUS
_ALIGNEDWINDOWSRESPONSE.fields_by_name['values'].message_type = _STATPOINT
_WINDOWSRESPONSE.fields_by_name['stat'].message_type = _STATUS
_WINDOWSRESPONSE.fields_by_name['values'].message_type = _STATPOINT
_STREAMINFOPARAMS.fields_by_name['role'].message_type = _ROLE
_STREAMINFORESPONSE.fields_by_name['stat'].message_type = _STATUS
_STREAMINFORESPONSE.fields_by_name['descriptor'].message_type = _STREAMDESCRIPTOR
_STREAMDESCRIPTOR.fields_by_name['tags'].message_type = _KEYOPTVALUE
_STREAMDESCRIPTOR.fields_by_name['annotations'].message_type = _KEYOPTVALUE
_SETSTREAMANNOTATIONSPARAMS.fields_by_name['changes'].message_type = _KEYOPTVALUE
_SETSTREAMANNOTATIONSRESPONSE.fields_by_name['stat'].message_type = _STATUS
_SETSTREAMTAGSPARAMS.fields_by_name['tags'].message_type = _KEYOPTVALUE
_SETSTREAMTAGSRESPONSE.fields_by_name['stat'].message_type = _STATUS
_CREATEPARAMS.fields_by_name['tags'].message_type = _KEYOPTVALUE
_CREATEPARAMS.fields_by_name['annotations'].message_type = _KEYOPTVALUE
_CREATERESPONSE.fields_by_name['stat'].message_type = _STATUS
_METADATAUSAGEPARAMS.fields_by_name['role'].message_type = _ROLE
_METADATAUSAGERESPONSE.fields_by_name['stat'].message_type = _STATUS
_METADATAUSAGERESPONSE.fields_by_name['tags'].message_type = _KEYCOUNT
_METADATAUSAGERESPONSE.fields_by_name['annotations'].message_type = _KEYCOUNT
_LISTCOLLECTIONSPARAMS.fields_by_name['role'].message_type = _ROLE
_LISTCOLLECTIONSRESPONSE.fields_by_name['stat'].message_type = _STATUS
_LOOKUPSTREAMSPARAMS.fields_by_name['tags'].message_type = _KEYOPTVALUE
_LOOKUPSTREAMSPARAMS.fields_by_name['annotations'].message_type = _KEYOPTVALUE
_LOOKUPSTREAMSPARAMS.fields_by_name['role'].message_type = _ROLE
_LOOKUPSTREAMSRESPONSE.fields_by_name['stat'].message_type = _STATUS
_LOOKUPSTREAMSRESPONSE.fields_by_name['results'].message_type = _STREAMDESCRIPTOR
_NEARESTRESPONSE.fields_by_name['stat'].message_type = _STATUS
_NEARESTRESPONSE.fields_by_name['value'].message_type = _RAWPOINT
_CHANGESRESPONSE.fields_by_name['stat'].message_type = _STATUS
_CHANGESRESPONSE.fields_by_name['ranges'].message_type = _CHANGEDRANGE
_INSERTPARAMS.fields_by_name['merge_policy'].enum_type = _MERGEPOLICY
_INSERTPARAMS.fields_by_name['values'].message_type = _RAWPOINT
_INSERTRESPONSE.fields_by_name['stat'].message_type = _STATUS
_DELETERESPONSE.fields_by_name['stat'].message_type = _STATUS
_INFORESPONSE.fields_by_name['stat'].message_type = _STATUS
_INFORESPONSE.fields_by_name['mash'].message_type = _MASH
_INFORESPONSE.fields_by_name['proxy'].message_type = _PROXYINFO
_FAULTINJECTRESPONSE.fields_by_name['stat'].message_type = _STATUS
_FLUSHRESPONSE.fields_by_name['stat'].message_type = _STATUS
_OBLITERATERESPONSE.fields_by_name['stat'].message_type = _STATUS
_STATUS.fields_by_name['mash'].message_type = _MASH
_MASH.fields_by_name['members'].message_type = _MEMBER
_KEYOPTVALUE.fields_by_name['val'].message_type = _OPTVALUE
_GENERATECSVPARAMS.fields_by_name['queryType'].enum_type = _GENERATECSVPARAMS_QUERYTYPE
_GENERATECSVPARAMS.fields_by_name['streams'].message_type = _STREAMCSVCONFIG
_GENERATECSVPARAMS_QUERYTYPE.containing_type = _GENERATECSVPARAMS
_GENERATECSVRESPONSE.fields_by_name['stat'].message_type = _STATUS
_SQLQUERYPARAMS.fields_by_name['role'].message_type = _ROLE
_SQLQUERYRESPONSE.fields_by_name['stat'].message_type = _STATUS
_SETCOMPACTIONCONFIGPARAMS.fields_by_name['reducedResolutionRanges'].message_type = _REDUCEDRESOLUTIONRANGE
_SETCOMPACTIONCONFIGRESPONSE.fields_by_name['stat'].message_type = _STATUS
_GETCOMPACTIONCONFIGRESPONSE.fields_by_name['stat'].message_type = _STATUS
_GETCOMPACTIONCONFIGRESPONSE.fields_by_name['reducedResolutionRanges'].message_type = _REDUCEDRESOLUTIONRANGE
DESCRIPTOR.message_types_by_name['RawValuesParams'] = _RAWVALUESPARAMS
DESCRIPTOR.message_types_by_name['RawValuesResponse'] = _RAWVALUESRESPONSE
DESCRIPTOR.message_types_by_name['AlignedWindowsParams'] = _ALIGNEDWINDOWSPARAMS
DESCRIPTOR.message_types_by_name['AlignedWindowsResponse'] = _ALIGNEDWINDOWSRESPONSE
DESCRIPTOR.message_types_by_name['WindowsParams'] = _WINDOWSPARAMS
DESCRIPTOR.message_types_by_name['WindowsResponse'] = _WINDOWSRESPONSE
DESCRIPTOR.message_types_by_name['StreamInfoParams'] = _STREAMINFOPARAMS
DESCRIPTOR.message_types_by_name['StreamInfoResponse'] = _STREAMINFORESPONSE
DESCRIPTOR.message_types_by_name['StreamDescriptor'] = _STREAMDESCRIPTOR
DESCRIPTOR.message_types_by_name['SetStreamAnnotationsParams'] = _SETSTREAMANNOTATIONSPARAMS
DESCRIPTOR.message_types_by_name['SetStreamAnnotationsResponse'] = _SETSTREAMANNOTATIONSRESPONSE
DESCRIPTOR.message_types_by_name['SetStreamTagsParams'] = _SETSTREAMTAGSPARAMS
DESCRIPTOR.message_types_by_name['SetStreamTagsResponse'] = _SETSTREAMTAGSRESPONSE
DESCRIPTOR.message_types_by_name['CreateParams'] = _CREATEPARAMS
DESCRIPTOR.message_types_by_name['CreateResponse'] = _CREATERESPONSE
DESCRIPTOR.message_types_by_name['MetadataUsageParams'] = _METADATAUSAGEPARAMS
DESCRIPTOR.message_types_by_name['MetadataUsageResponse'] = _METADATAUSAGERESPONSE
DESCRIPTOR.message_types_by_name['KeyCount'] = _KEYCOUNT
DESCRIPTOR.message_types_by_name['ListCollectionsParams'] = _LISTCOLLECTIONSPARAMS
DESCRIPTOR.message_types_by_name['ListCollectionsResponse'] = _LISTCOLLECTIONSRESPONSE
DESCRIPTOR.message_types_by_name['LookupStreamsParams'] = _LOOKUPSTREAMSPARAMS
DESCRIPTOR.message_types_by_name['LookupStreamsResponse'] = _LOOKUPSTREAMSRESPONSE
DESCRIPTOR.message_types_by_name['NearestParams'] = _NEARESTPARAMS
DESCRIPTOR.message_types_by_name['NearestResponse'] = _NEARESTRESPONSE
DESCRIPTOR.message_types_by_name['ChangesParams'] = _CHANGESPARAMS
DESCRIPTOR.message_types_by_name['ChangesResponse'] = _CHANGESRESPONSE
DESCRIPTOR.message_types_by_name['InsertParams'] = _INSERTPARAMS
DESCRIPTOR.message_types_by_name['InsertResponse'] = _INSERTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteParams'] = _DELETEPARAMS
DESCRIPTOR.message_types_by_name['DeleteResponse'] = _DELETERESPONSE
DESCRIPTOR.message_types_by_name['InfoParams'] = _INFOPARAMS
DESCRIPTOR.message_types_by_name['InfoResponse'] = _INFORESPONSE
DESCRIPTOR.message_types_by_name['ProxyInfo'] = _PROXYINFO
DESCRIPTOR.message_types_by_name['FaultInjectParams'] = _FAULTINJECTPARAMS
DESCRIPTOR.message_types_by_name['FaultInjectResponse'] = _FAULTINJECTRESPONSE
DESCRIPTOR.message_types_by_name['FlushParams'] = _FLUSHPARAMS
DESCRIPTOR.message_types_by_name['FlushResponse'] = _FLUSHRESPONSE
DESCRIPTOR.message_types_by_name['ObliterateParams'] = _OBLITERATEPARAMS
DESCRIPTOR.message_types_by_name['ObliterateResponse'] = _OBLITERATERESPONSE
DESCRIPTOR.message_types_by_name['RawPoint'] = _RAWPOINT
DESCRIPTOR.message_types_by_name['StatPoint'] = _STATPOINT
DESCRIPTOR.message_types_by_name['ChangedRange'] = _CHANGEDRANGE
DESCRIPTOR.message_types_by_name['Status'] = _STATUS
DESCRIPTOR.message_types_by_name['Mash'] = _MASH
DESCRIPTOR.message_types_by_name['Member'] = _MEMBER
DESCRIPTOR.message_types_by_name['KeyOptValue'] = _KEYOPTVALUE
DESCRIPTOR.message_types_by_name['OptValue'] = _OPTVALUE
DESCRIPTOR.message_types_by_name['KeyValue'] = _KEYVALUE
DESCRIPTOR.message_types_by_name['StreamCSVConfig'] = _STREAMCSVCONFIG
DESCRIPTOR.message_types_by_name['GenerateCSVParams'] = _GENERATECSVPARAMS
DESCRIPTOR.message_types_by_name['GenerateCSVResponse'] = _GENERATECSVRESPONSE
DESCRIPTOR.message_types_by_name['SQLQueryParams'] = _SQLQUERYPARAMS
DESCRIPTOR.message_types_by_name['SQLQueryResponse'] = _SQLQUERYRESPONSE
DESCRIPTOR.message_types_by_name['Role'] = _ROLE
DESCRIPTOR.message_types_by_name['SetCompactionConfigParams'] = _SETCOMPACTIONCONFIGPARAMS
DESCRIPTOR.message_types_by_name['SetCompactionConfigResponse'] = _SETCOMPACTIONCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['GetCompactionConfigParams'] = _GETCOMPACTIONCONFIGPARAMS
DESCRIPTOR.message_types_by_name['GetCompactionConfigResponse'] = _GETCOMPACTIONCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['ReducedResolutionRange'] = _REDUCEDRESOLUTIONRANGE
DESCRIPTOR.enum_types_by_name['MergePolicy'] = _MERGEPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RawValuesParams = _reflection.GeneratedProtocolMessageType('RawValuesParams', (_message.Message,), dict(
  DESCRIPTOR = _RAWVALUESPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.RawValuesParams)
  ))
_sym_db.RegisterMessage(RawValuesParams)

RawValuesResponse = _reflection.GeneratedProtocolMessageType('RawValuesResponse', (_message.Message,), dict(
  DESCRIPTOR = _RAWVALUESRESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.RawValuesResponse)
  ))
_sym_db.RegisterMessage(RawValuesResponse)

AlignedWindowsParams = _reflection.GeneratedProtocolMessageType('AlignedWindowsParams', (_message.Message,), dict(
  DESCRIPTOR = _ALIGNEDWINDOWSPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.AlignedWindowsParams)
  ))
_sym_db.RegisterMessage(AlignedWindowsParams)

AlignedWindowsResponse = _reflection.GeneratedProtocolMessageType('AlignedWindowsResponse', (_message.Message,), dict(
  DESCRIPTOR = _ALIGNEDWINDOWSRESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.AlignedWindowsResponse)
  ))
_sym_db.RegisterMessage(AlignedWindowsResponse)

WindowsParams = _reflection.GeneratedProtocolMessageType('WindowsParams', (_message.Message,), dict(
  DESCRIPTOR = _WINDOWSPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.WindowsParams)
  ))
_sym_db.RegisterMessage(WindowsParams)

WindowsResponse = _reflection.GeneratedProtocolMessageType('WindowsResponse', (_message.Message,), dict(
  DESCRIPTOR = _WINDOWSRESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.WindowsResponse)
  ))
_sym_db.RegisterMessage(WindowsResponse)

StreamInfoParams = _reflection.GeneratedProtocolMessageType('StreamInfoParams', (_message.Message,), dict(
  DESCRIPTOR = _STREAMINFOPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.StreamInfoParams)
  ))
_sym_db.RegisterMessage(StreamInfoParams)

StreamInfoResponse = _reflection.GeneratedProtocolMessageType('StreamInfoResponse', (_message.Message,), dict(
  DESCRIPTOR = _STREAMINFORESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.StreamInfoResponse)
  ))
_sym_db.RegisterMessage(StreamInfoResponse)

StreamDescriptor = _reflection.GeneratedProtocolMessageType('StreamDescriptor', (_message.Message,), dict(
  DESCRIPTOR = _STREAMDESCRIPTOR,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.StreamDescriptor)
  ))
_sym_db.RegisterMessage(StreamDescriptor)

SetStreamAnnotationsParams = _reflection.GeneratedProtocolMessageType('SetStreamAnnotationsParams', (_message.Message,), dict(
  DESCRIPTOR = _SETSTREAMANNOTATIONSPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.SetStreamAnnotationsParams)
  ))
_sym_db.RegisterMessage(SetStreamAnnotationsParams)

SetStreamAnnotationsResponse = _reflection.GeneratedProtocolMessageType('SetStreamAnnotationsResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETSTREAMANNOTATIONSRESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.SetStreamAnnotationsResponse)
  ))
_sym_db.RegisterMessage(SetStreamAnnotationsResponse)

SetStreamTagsParams = _reflection.GeneratedProtocolMessageType('SetStreamTagsParams', (_message.Message,), dict(
  DESCRIPTOR = _SETSTREAMTAGSPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.SetStreamTagsParams)
  ))
_sym_db.RegisterMessage(SetStreamTagsParams)

SetStreamTagsResponse = _reflection.GeneratedProtocolMessageType('SetStreamTagsResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETSTREAMTAGSRESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.SetStreamTagsResponse)
  ))
_sym_db.RegisterMessage(SetStreamTagsResponse)

CreateParams = _reflection.GeneratedProtocolMessageType('CreateParams', (_message.Message,), dict(
  DESCRIPTOR = _CREATEPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.CreateParams)
  ))
_sym_db.RegisterMessage(CreateParams)

CreateResponse = _reflection.GeneratedProtocolMessageType('CreateResponse', (_message.Message,), dict(
  DESCRIPTOR = _CREATERESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.CreateResponse)
  ))
_sym_db.RegisterMessage(CreateResponse)

MetadataUsageParams = _reflection.GeneratedProtocolMessageType('MetadataUsageParams', (_message.Message,), dict(
  DESCRIPTOR = _METADATAUSAGEPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.MetadataUsageParams)
  ))
_sym_db.RegisterMessage(MetadataUsageParams)

MetadataUsageResponse = _reflection.GeneratedProtocolMessageType('MetadataUsageResponse', (_message.Message,), dict(
  DESCRIPTOR = _METADATAUSAGERESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.MetadataUsageResponse)
  ))
_sym_db.RegisterMessage(MetadataUsageResponse)

KeyCount = _reflection.GeneratedProtocolMessageType('KeyCount', (_message.Message,), dict(
  DESCRIPTOR = _KEYCOUNT,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.KeyCount)
  ))
_sym_db.RegisterMessage(KeyCount)

ListCollectionsParams = _reflection.GeneratedProtocolMessageType('ListCollectionsParams', (_message.Message,), dict(
  DESCRIPTOR = _LISTCOLLECTIONSPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.ListCollectionsParams)
  ))
_sym_db.RegisterMessage(ListCollectionsParams)

ListCollectionsResponse = _reflection.GeneratedProtocolMessageType('ListCollectionsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTCOLLECTIONSRESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.ListCollectionsResponse)
  ))
_sym_db.RegisterMessage(ListCollectionsResponse)

LookupStreamsParams = _reflection.GeneratedProtocolMessageType('LookupStreamsParams', (_message.Message,), dict(
  DESCRIPTOR = _LOOKUPSTREAMSPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.LookupStreamsParams)
  ))
_sym_db.RegisterMessage(LookupStreamsParams)

LookupStreamsResponse = _reflection.GeneratedProtocolMessageType('LookupStreamsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LOOKUPSTREAMSRESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.LookupStreamsResponse)
  ))
_sym_db.RegisterMessage(LookupStreamsResponse)

NearestParams = _reflection.GeneratedProtocolMessageType('NearestParams', (_message.Message,), dict(
  DESCRIPTOR = _NEARESTPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.NearestParams)
  ))
_sym_db.RegisterMessage(NearestParams)

NearestResponse = _reflection.GeneratedProtocolMessageType('NearestResponse', (_message.Message,), dict(
  DESCRIPTOR = _NEARESTRESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.NearestResponse)
  ))
_sym_db.RegisterMessage(NearestResponse)

ChangesParams = _reflection.GeneratedProtocolMessageType('ChangesParams', (_message.Message,), dict(
  DESCRIPTOR = _CHANGESPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.ChangesParams)
  ))
_sym_db.RegisterMessage(ChangesParams)

ChangesResponse = _reflection.GeneratedProtocolMessageType('ChangesResponse', (_message.Message,), dict(
  DESCRIPTOR = _CHANGESRESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.ChangesResponse)
  ))
_sym_db.RegisterMessage(ChangesResponse)

InsertParams = _reflection.GeneratedProtocolMessageType('InsertParams', (_message.Message,), dict(
  DESCRIPTOR = _INSERTPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.InsertParams)
  ))
_sym_db.RegisterMessage(InsertParams)

InsertResponse = _reflection.GeneratedProtocolMessageType('InsertResponse', (_message.Message,), dict(
  DESCRIPTOR = _INSERTRESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.InsertResponse)
  ))
_sym_db.RegisterMessage(InsertResponse)

DeleteParams = _reflection.GeneratedProtocolMessageType('DeleteParams', (_message.Message,), dict(
  DESCRIPTOR = _DELETEPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.DeleteParams)
  ))
_sym_db.RegisterMessage(DeleteParams)

DeleteResponse = _reflection.GeneratedProtocolMessageType('DeleteResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETERESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.DeleteResponse)
  ))
_sym_db.RegisterMessage(DeleteResponse)

InfoParams = _reflection.GeneratedProtocolMessageType('InfoParams', (_message.Message,), dict(
  DESCRIPTOR = _INFOPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.InfoParams)
  ))
_sym_db.RegisterMessage(InfoParams)

InfoResponse = _reflection.GeneratedProtocolMessageType('InfoResponse', (_message.Message,), dict(
  DESCRIPTOR = _INFORESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.InfoResponse)
  ))
_sym_db.RegisterMessage(InfoResponse)

ProxyInfo = _reflection.GeneratedProtocolMessageType('ProxyInfo', (_message.Message,), dict(
  DESCRIPTOR = _PROXYINFO,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.ProxyInfo)
  ))
_sym_db.RegisterMessage(ProxyInfo)

FaultInjectParams = _reflection.GeneratedProtocolMessageType('FaultInjectParams', (_message.Message,), dict(
  DESCRIPTOR = _FAULTINJECTPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.FaultInjectParams)
  ))
_sym_db.RegisterMessage(FaultInjectParams)

FaultInjectResponse = _reflection.GeneratedProtocolMessageType('FaultInjectResponse', (_message.Message,), dict(
  DESCRIPTOR = _FAULTINJECTRESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.FaultInjectResponse)
  ))
_sym_db.RegisterMessage(FaultInjectResponse)

FlushParams = _reflection.GeneratedProtocolMessageType('FlushParams', (_message.Message,), dict(
  DESCRIPTOR = _FLUSHPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.FlushParams)
  ))
_sym_db.RegisterMessage(FlushParams)

FlushResponse = _reflection.GeneratedProtocolMessageType('FlushResponse', (_message.Message,), dict(
  DESCRIPTOR = _FLUSHRESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.FlushResponse)
  ))
_sym_db.RegisterMessage(FlushResponse)

ObliterateParams = _reflection.GeneratedProtocolMessageType('ObliterateParams', (_message.Message,), dict(
  DESCRIPTOR = _OBLITERATEPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.ObliterateParams)
  ))
_sym_db.RegisterMessage(ObliterateParams)

ObliterateResponse = _reflection.GeneratedProtocolMessageType('ObliterateResponse', (_message.Message,), dict(
  DESCRIPTOR = _OBLITERATERESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.ObliterateResponse)
  ))
_sym_db.RegisterMessage(ObliterateResponse)

RawPoint = _reflection.GeneratedProtocolMessageType('RawPoint', (_message.Message,), dict(
  DESCRIPTOR = _RAWPOINT,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.RawPoint)
  ))
_sym_db.RegisterMessage(RawPoint)

StatPoint = _reflection.GeneratedProtocolMessageType('StatPoint', (_message.Message,), dict(
  DESCRIPTOR = _STATPOINT,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.StatPoint)
  ))
_sym_db.RegisterMessage(StatPoint)

ChangedRange = _reflection.GeneratedProtocolMessageType('ChangedRange', (_message.Message,), dict(
  DESCRIPTOR = _CHANGEDRANGE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.ChangedRange)
  ))
_sym_db.RegisterMessage(ChangedRange)

Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), dict(
  DESCRIPTOR = _STATUS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.Status)
  ))
_sym_db.RegisterMessage(Status)

Mash = _reflection.GeneratedProtocolMessageType('Mash', (_message.Message,), dict(
  DESCRIPTOR = _MASH,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.Mash)
  ))
_sym_db.RegisterMessage(Mash)

Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
  DESCRIPTOR = _MEMBER,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.Member)
  ))
_sym_db.RegisterMessage(Member)

KeyOptValue = _reflection.GeneratedProtocolMessageType('KeyOptValue', (_message.Message,), dict(
  DESCRIPTOR = _KEYOPTVALUE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.KeyOptValue)
  ))
_sym_db.RegisterMessage(KeyOptValue)

OptValue = _reflection.GeneratedProtocolMessageType('OptValue', (_message.Message,), dict(
  DESCRIPTOR = _OPTVALUE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.OptValue)
  ))
_sym_db.RegisterMessage(OptValue)

KeyValue = _reflection.GeneratedProtocolMessageType('KeyValue', (_message.Message,), dict(
  DESCRIPTOR = _KEYVALUE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.KeyValue)
  ))
_sym_db.RegisterMessage(KeyValue)

StreamCSVConfig = _reflection.GeneratedProtocolMessageType('StreamCSVConfig', (_message.Message,), dict(
  DESCRIPTOR = _STREAMCSVCONFIG,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.StreamCSVConfig)
  ))
_sym_db.RegisterMessage(StreamCSVConfig)

GenerateCSVParams = _reflection.GeneratedProtocolMessageType('GenerateCSVParams', (_message.Message,), dict(
  DESCRIPTOR = _GENERATECSVPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.GenerateCSVParams)
  ))
_sym_db.RegisterMessage(GenerateCSVParams)

GenerateCSVResponse = _reflection.GeneratedProtocolMessageType('GenerateCSVResponse', (_message.Message,), dict(
  DESCRIPTOR = _GENERATECSVRESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.GenerateCSVResponse)
  ))
_sym_db.RegisterMessage(GenerateCSVResponse)

SQLQueryParams = _reflection.GeneratedProtocolMessageType('SQLQueryParams', (_message.Message,), dict(
  DESCRIPTOR = _SQLQUERYPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.SQLQueryParams)
  ))
_sym_db.RegisterMessage(SQLQueryParams)

SQLQueryResponse = _reflection.GeneratedProtocolMessageType('SQLQueryResponse', (_message.Message,), dict(
  DESCRIPTOR = _SQLQUERYRESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.SQLQueryResponse)
  ))
_sym_db.RegisterMessage(SQLQueryResponse)

Role = _reflection.GeneratedProtocolMessageType('Role', (_message.Message,), dict(
  DESCRIPTOR = _ROLE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.Role)
  ))
_sym_db.RegisterMessage(Role)

SetCompactionConfigParams = _reflection.GeneratedProtocolMessageType('SetCompactionConfigParams', (_message.Message,), dict(
  DESCRIPTOR = _SETCOMPACTIONCONFIGPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.SetCompactionConfigParams)
  ))
_sym_db.RegisterMessage(SetCompactionConfigParams)

SetCompactionConfigResponse = _reflection.GeneratedProtocolMessageType('SetCompactionConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCOMPACTIONCONFIGRESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.SetCompactionConfigResponse)
  ))
_sym_db.RegisterMessage(SetCompactionConfigResponse)

GetCompactionConfigParams = _reflection.GeneratedProtocolMessageType('GetCompactionConfigParams', (_message.Message,), dict(
  DESCRIPTOR = _GETCOMPACTIONCONFIGPARAMS,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.GetCompactionConfigParams)
  ))
_sym_db.RegisterMessage(GetCompactionConfigParams)

GetCompactionConfigResponse = _reflection.GeneratedProtocolMessageType('GetCompactionConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCOMPACTIONCONFIGRESPONSE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.GetCompactionConfigResponse)
  ))
_sym_db.RegisterMessage(GetCompactionConfigResponse)

ReducedResolutionRange = _reflection.GeneratedProtocolMessageType('ReducedResolutionRange', (_message.Message,), dict(
  DESCRIPTOR = _REDUCEDRESOLUTIONRANGE,
  __module__ = 'btrdb_pb2'
  # @@protoc_insertion_point(class_scope:v5api.ReducedResolutionRange)
  ))
_sym_db.RegisterMessage(ReducedResolutionRange)



_BTRDB = _descriptor.ServiceDescriptor(
  name='BTrDB',
  full_name='v5api.BTrDB',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=5553,
  serialized_end=6884,
  methods=[
  _descriptor.MethodDescriptor(
    name='RawValues',
    full_name='v5api.BTrDB.RawValues',
    index=0,
    containing_service=None,
    input_type=_RAWVALUESPARAMS,
    output_type=_RAWVALUESRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AlignedWindows',
    full_name='v5api.BTrDB.AlignedWindows',
    index=1,
    containing_service=None,
    input_type=_ALIGNEDWINDOWSPARAMS,
    output_type=_ALIGNEDWINDOWSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Windows',
    full_name='v5api.BTrDB.Windows',
    index=2,
    containing_service=None,
    input_type=_WINDOWSPARAMS,
    output_type=_WINDOWSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='StreamInfo',
    full_name='v5api.BTrDB.StreamInfo',
    index=3,
    containing_service=None,
    input_type=_STREAMINFOPARAMS,
    output_type=_STREAMINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetStreamAnnotations',
    full_name='v5api.BTrDB.SetStreamAnnotations',
    index=4,
    containing_service=None,
    input_type=_SETSTREAMANNOTATIONSPARAMS,
    output_type=_SETSTREAMANNOTATIONSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetStreamTags',
    full_name='v5api.BTrDB.SetStreamTags',
    index=5,
    containing_service=None,
    input_type=_SETSTREAMTAGSPARAMS,
    output_type=_SETSTREAMTAGSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='v5api.BTrDB.Create',
    index=6,
    containing_service=None,
    input_type=_CREATEPARAMS,
    output_type=_CREATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListCollections',
    full_name='v5api.BTrDB.ListCollections',
    index=7,
    containing_service=None,
    input_type=_LISTCOLLECTIONSPARAMS,
    output_type=_LISTCOLLECTIONSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='LookupStreams',
    full_name='v5api.BTrDB.LookupStreams',
    index=8,
    containing_service=None,
    input_type=_LOOKUPSTREAMSPARAMS,
    output_type=_LOOKUPSTREAMSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Nearest',
    full_name='v5api.BTrDB.Nearest',
    index=9,
    containing_service=None,
    input_type=_NEARESTPARAMS,
    output_type=_NEARESTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Changes',
    full_name='v5api.BTrDB.Changes',
    index=10,
    containing_service=None,
    input_type=_CHANGESPARAMS,
    output_type=_CHANGESRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Insert',
    full_name='v5api.BTrDB.Insert',
    index=11,
    containing_service=None,
    input_type=_INSERTPARAMS,
    output_type=_INSERTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='v5api.BTrDB.Delete',
    index=12,
    containing_service=None,
    input_type=_DELETEPARAMS,
    output_type=_DELETERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Info',
    full_name='v5api.BTrDB.Info',
    index=13,
    containing_service=None,
    input_type=_INFOPARAMS,
    output_type=_INFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='FaultInject',
    full_name='v5api.BTrDB.FaultInject',
    index=14,
    containing_service=None,
    input_type=_FAULTINJECTPARAMS,
    output_type=_FAULTINJECTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Flush',
    full_name='v5api.BTrDB.Flush',
    index=15,
    containing_service=None,
    input_type=_FLUSHPARAMS,
    output_type=_FLUSHRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Obliterate',
    full_name='v5api.BTrDB.Obliterate',
    index=16,
    containing_service=None,
    input_type=_OBLITERATEPARAMS,
    output_type=_OBLITERATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetMetadataUsage',
    full_name='v5api.BTrDB.GetMetadataUsage',
    index=17,
    containing_service=None,
    input_type=_METADATAUSAGEPARAMS,
    output_type=_METADATAUSAGERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GenerateCSV',
    full_name='v5api.BTrDB.GenerateCSV',
    index=18,
    containing_service=None,
    input_type=_GENERATECSVPARAMS,
    output_type=_GENERATECSVRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SQLQuery',
    full_name='v5api.BTrDB.SQLQuery',
    index=19,
    containing_service=None,
    input_type=_SQLQUERYPARAMS,
    output_type=_SQLQUERYRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_BTRDB)

DESCRIPTOR.services_by_name['BTrDB'] = _BTRDB

# @@protoc_insertion_point(module_scope)
